@@ -311,6 +311,9 @@ types: list[str] = [
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
     "AWS::Connect::ContactFlowVersion",
+    "AWS::Connect::DataTable",
+    "AWS::Connect::DataTableAttribute",
+    "AWS::Connect::DataTableRecord",
     "AWS::Connect::EmailAddress",
     "AWS::Connect::EvaluationForm",
     "AWS::Connect::HoursOfOperation",
@@ -412,6 +415,8 @@ types: list[str] = [
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
     "AWS::Detective::OrganizationAdmin",
+    "AWS::DevOpsAgent::AgentSpace",
+    "AWS::DevOpsAgent::Association",
     "AWS::DevOpsGuru::LogAnomalyDetectionIntegration",
     "AWS::DevOpsGuru::NotificationChannel",
     "AWS::DevOpsGuru::ResourceCollection",
@@ -662,6 +667,7 @@ types: list[str] = [
     "AWS::Glue::DataQualityRuleset",
     "AWS::Glue::Database",
     "AWS::Glue::DevEndpoint",
+    "AWS::Glue::IdentityCenterConfiguration",
     "AWS::Glue::Integration",
     "AWS::Glue::IntegrationResourceProperty",
     "AWS::Glue::Job",
@@ -862,6 +868,7 @@ types: list[str] = [
     "AWS::LakeFormation::Tag",
     "AWS::LakeFormation::TagAssociation",
     "AWS::Lambda::Alias",
+    "AWS::Lambda::CapacityProvider",
     "AWS::Lambda::CodeSigningConfig",
     "AWS::Lambda::EventInvokeConfig",
     "AWS::Lambda::EventSourceMapping",
@@ -1036,6 +1043,8 @@ types: list[str] = [
     "AWS::Oam::Sink",
     "AWS::ObservabilityAdmin::OrganizationCentralizationRule",
     "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
+    "AWS::ObservabilityAdmin::S3TableIntegration",
+    "AWS::ObservabilityAdmin::TelemetryPipelines",
     "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::Omics::AnnotationStore",
     "AWS::Omics::ReferenceStore",
@@ -1351,6 +1360,7 @@ types: list[str] = [
     "AWS::SecurityHub::AutomationRule",
     "AWS::SecurityHub::AutomationRuleV2",
     "AWS::SecurityHub::ConfigurationPolicy",
+    "AWS::SecurityHub::ConnectorV2",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::FindingAggregator",
     "AWS::SecurityHub::Hub",
