@@ -6,6 +6,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
@@ -167,6 +168,7 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionFunction",
     "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
@@ -181,6 +183,7 @@ types: list[str] = [
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
+    "AWS::CloudFront::TrustStore",
     "AWS::CloudFront::VpcOrigin",
     "AWS::CloudTrail::Channel",
     "AWS::CloudTrail::Dashboard",
@@ -281,6 +284,7 @@ types: list[str] = [
     "AWS::DirectoryService::SimpleAD",
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
+    "AWS::EC2::CapacityManagerDataExport",
     "AWS::EC2::CapacityReservation",
     "AWS::EC2::CapacityReservationFleet",
     "AWS::EC2::ClientVpnAuthorizationRule",
@@ -354,6 +358,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
     "AWS::EC2::TransitGatewayConnectPeer",
+    "AWS::EC2::TransitGatewayMeteringPolicy",
+    "AWS::EC2::TransitGatewayMeteringPolicyEntry",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -369,12 +375,14 @@ types: list[str] = [
     "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
+    "AWS::EC2::VPCEncryptionControl",
     "AWS::EC2::VPCEndpoint",
     "AWS::EC2::VPCEndpointConnectionNotification",
     "AWS::EC2::VPCEndpointService",
     "AWS::EC2::VPCEndpointServicePermissions",
     "AWS::EC2::VPCGatewayAttachment",
     "AWS::EC2::VPCPeeringConnection",
+    "AWS::EC2::VPNConcentrator",
     "AWS::EC2::VPNConnection",
     "AWS::EC2::VPNConnectionRoute",
     "AWS::EC2::VPNGateway",
@@ -386,14 +394,17 @@ types: list[str] = [
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
+    "AWS::ECR::PullTimeUpdateExclusion",
     "AWS::ECR::RegistryPolicy",
     "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
+    "AWS::ECR::SigningConfiguration",
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
     "AWS::ECS::ClusterCapacityProviderAssociations",
+    "AWS::ECS::ExpressGatewayService",
     "AWS::ECS::PrimaryTaskSet",
     "AWS::ECS::Service",
     "AWS::ECS::TaskDefinition",
@@ -403,6 +414,7 @@ types: list[str] = [
     "AWS::EFS::MountTarget",
     "AWS::EKS::AccessEntry",
     "AWS::EKS::Addon",
+    "AWS::EKS::Capability",
     "AWS::EKS::Cluster",
     "AWS::EKS::FargateProfile",
     "AWS::EKS::IdentityProviderConfig",
@@ -415,6 +427,7 @@ types: list[str] = [
     "AWS::EMR::Step",
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
+    "AWS::EMR::WALWorkspace",
     "AWS::EMRContainers::VirtualCluster",
     "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
@@ -458,6 +471,7 @@ types: list[str] = [
     "AWS::FMS::ResourceSet",
     "AWS::FSx::DataRepositoryAssociation",
     "AWS::FSx::FileSystem",
+    "AWS::FSx::S3AccessPointAttachment",
     "AWS::FSx::Snapshot",
     "AWS::FSx::StorageVirtualMachine",
     "AWS::FSx::Volume",
@@ -483,6 +497,7 @@ types: list[str] = [
     "AWS::Glue::DataQualityRuleset",
     "AWS::Glue::Database",
     "AWS::Glue::DevEndpoint",
+    "AWS::Glue::IdentityCenterConfiguration",
     "AWS::Glue::Job",
     "AWS::Glue::MLTransform",
     "AWS::Glue::Partition",
@@ -659,6 +674,9 @@ types: list[str] = [
     "AWS::MediaConnect::FlowSource",
     "AWS::MediaConnect::FlowVpcInterface",
     "AWS::MediaConnect::Gateway",
+    "AWS::MediaConnect::RouterInput",
+    "AWS::MediaConnect::RouterNetworkInterface",
+    "AWS::MediaConnect::RouterOutput",
     "AWS::MediaConvert::JobTemplate",
     "AWS::MediaConvert::Preset",
     "AWS::MediaConvert::Queue",
@@ -710,6 +728,7 @@ types: list[str] = [
     "AWS::Oam::Sink",
     "AWS::ObservabilityAdmin::OrganizationCentralizationRule",
     "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
+    "AWS::ObservabilityAdmin::TelemetryPipelines",
     "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
@@ -843,6 +862,7 @@ types: list[str] = [
     "AWS::SES::MailManagerRelay",
     "AWS::SES::MailManagerRuleSet",
     "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
     "AWS::SES::ReceiptFilter",
     "AWS::SES::ReceiptRule",
     "AWS::SES::ReceiptRuleSet",
@@ -879,6 +899,7 @@ types: list[str] = [
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
+    "AWS::SSMQuickSetup::LifecycleAutomation",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -926,6 +947,7 @@ types: list[str] = [
     "AWS::SecurityHub::AutomationRule",
     "AWS::SecurityHub::AutomationRuleV2",
     "AWS::SecurityHub::ConfigurationPolicy",
+    "AWS::SecurityHub::ConnectorV2",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::FindingAggregator",
     "AWS::SecurityHub::Hub",
@@ -992,6 +1014,7 @@ types: list[str] = [
     "AWS::VerifiedPermissions::PolicyTemplate",
     "AWS::VpcLattice::AccessLogSubscription",
     "AWS::VpcLattice::AuthPolicy",
+    "AWS::VpcLattice::DomainVerification",
     "AWS::VpcLattice::Listener",
     "AWS::VpcLattice::ResourceConfiguration",
     "AWS::VpcLattice::ResourceGateway",
@@ -1064,11 +1087,14 @@ cached: list[str] = [
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
+    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -1088,8 +1114,6 @@ cached: list[str] = [
     "aws-apigatewayv2-stage.json",
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
-    "aws-appconfig-configurationprofile.json",
-    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -1124,8 +1148,10 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
+    "aws-aps-scraper.json",
     "aws-aps-workspace.json",
     "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
@@ -1133,7 +1159,6 @@ cached: list[str] = [
     "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
-    "aws-athena-workgroup.json",
     "aws-auditmanager-assessment.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
@@ -1157,7 +1182,6 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
@@ -1194,6 +1218,7 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectionfunction.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
@@ -1208,6 +1233,7 @@ cached: list[str] = [
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-streamingdistribution.json",
+    "aws-cloudfront-truststore.json",
     "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-channel.json",
     "aws-cloudtrail-dashboard.json",
@@ -1306,6 +1332,7 @@ cached: list[str] = [
     "aws-dms-replicationtask.json",
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
+    "aws-ec2-capacitymanagerdataexport.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnauthorizationrule.json",
@@ -1341,7 +1368,6 @@ cached: list[str] = [
     "aws-ec2-localgatewayroutetablevpcassociation.json",
     "aws-ec2-localgatewayvirtualinterface.json",
     "aws-ec2-localgatewayvirtualinterfacegroup.json",
-    "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinsightsaccessscope.json",
@@ -1379,6 +1405,8 @@ cached: list[str] = [
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
     "aws-ec2-transitgatewayconnectpeer.json",
+    "aws-ec2-transitgatewaymeteringpolicy.json",
+    "aws-ec2-transitgatewaymeteringpolicyentry.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1400,25 +1428,30 @@ cached: list[str] = [
     "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcencryptioncontrol.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconcentrator.json",
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
+    "aws-ecr-pulltimeupdateexclusion.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
+    "aws-ecr-signingconfiguration.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
+    "aws-ecs-expressgatewayservice.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
@@ -1428,10 +1461,10 @@ cached: list[str] = [
     "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
+    "aws-eks-capability.json",
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1463,6 +1496,7 @@ cached: list[str] = [
     "aws-emr-step.json",
     "aws-emr-studio.json",
     "aws-emr-studiosessionmapping.json",
+    "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
     "aws-events-apidestination.json",
@@ -1505,6 +1539,7 @@ cached: list[str] = [
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
+    "aws-glue-identitycenterconfiguration.json",
     "aws-glue-job.json",
     "aws-glue-mltransform.json",
     "aws-glue-partition.json",
@@ -1554,7 +1589,6 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
-    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -1619,27 +1653,26 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
-    "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
@@ -1657,6 +1690,9 @@ cached: list[str] = [
     "aws-mediaconnect-flowsource.json",
     "aws-mediaconnect-flowvpcinterface.json",
     "aws-mediaconnect-gateway.json",
+    "aws-mediaconnect-routerinput.json",
+    "aws-mediaconnect-routernetworkinterface.json",
+    "aws-mediaconnect-routeroutput.json",
     "aws-mediaconvert-jobtemplate.json",
     "aws-mediaconvert-preset.json",
     "aws-mediaconvert-queue.json",
@@ -1677,7 +1713,6 @@ cached: list[str] = [
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
     "aws-msk-batchscramsecret.json",
-    "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-replicator.json",
@@ -1695,19 +1730,26 @@ cached: list[str] = [
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
+    "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-observabilityadmin-organizationcentralizationrule.json",
     "aws-observabilityadmin-organizationtelemetryrule.json",
+    "aws-observabilityadmin-telemetrypipelines.json",
     "aws-observabilityadmin-telemetryrule.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
@@ -1728,8 +1770,8 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-osis-pipeline.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
@@ -1808,11 +1850,9 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
-    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
-    "aws-s3-storagelens.json",
     "aws-s3-storagelensgroup.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
@@ -1821,8 +1861,6 @@ cached: list[str] = [
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
     "aws-s3tables-namespace.json",
-    "aws-s3tables-table.json",
-    "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-s3tables-tablepolicy.json",
     "aws-sagemaker-app.json",
@@ -1851,7 +1889,6 @@ cached: list[str] = [
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
@@ -1866,6 +1903,7 @@ cached: list[str] = [
     "aws-securityhub-automationrule.json",
     "aws-securityhub-automationrulev2.json",
     "aws-securityhub-configurationpolicy.json",
+    "aws-securityhub-connectorv2.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-findingaggregator.json",
     "aws-securityhub-hub.json",
@@ -1887,6 +1925,7 @@ cached: list[str] = [
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
     "aws-servicecatalog-portfolio.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
     "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
     "aws-servicecatalog-resourceupdateconstraint.json",
@@ -1917,6 +1956,7 @@ cached: list[str] = [
     "aws-ses-mailmanagerrelay.json",
     "aws-ses-mailmanagerruleset.json",
     "aws-ses-mailmanagertrafficpolicy.json",
+    "aws-ses-multiregionendpoint.json",
     "aws-ses-receiptfilter.json",
     "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
@@ -1959,6 +1999,7 @@ cached: list[str] = [
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
     "aws-ssmquicksetup-configurationmanager.json",
+    "aws-ssmquicksetup-lifecycleautomation.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
@@ -1984,9 +2025,13 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-domainverification.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
+    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
