@@ -17,7 +17,7 @@ import sys
 import zipfile
 from copy import copy
 from functools import lru_cache
-from typing import Any, Dict, Iterator, Sequence
+from typing import TYPE_CHECKING, Any, Dict, Iterator, Sequence
 
 import jsonpatch
 import jsonpointer
@@ -33,7 +33,9 @@ from cfnlint.helpers import (
 from cfnlint.schema._exceptions import ResourceNotFoundError
 from cfnlint.schema._getatts import AttributeDict
 from cfnlint.schema._schema import Schema
-from cfnlint.schema.patch import SchemaPatch
+
+if TYPE_CHECKING:
+    from cfnlint.schema._patch import SchemaPatch
 
 LOGGER = logging.getLogger(__name__)
 
@@ -282,7 +284,7 @@ class ProviderSchemaManager:
 
         multiprocessing_logger.debug("Downloading template %s into %s", url, directory)
 
-        if "iso" in region:
+        if "iso" in region or region.startswith("eusc"):
             all_types = ["AWS::CDK::Metadata", "Module"]
             cached = ["Module"]
             filenames = [
@@ -396,7 +398,6 @@ class ProviderSchemaManager:
             LOGGER.info("Issuing updating schemas for %s: %s", region, e)
 
     def patch_schemas(self) -> None:
-
         self._patch_region_schemas(self._region_primary.name)
         # pylint: disable=not-context-manager
         with multiprocessing.Pool() as pool:
@@ -515,33 +516,7 @@ class ProviderSchemaManager:
 
         return content
 
-    def patch(self, filename: str, regions: Sequence[str]):
-        try:
-            with open(filename, encoding="utf-8") as fp:
-                custom_spec_data = json.load(fp)
-                schema_patch = SchemaPatch.from_dict(custom_spec_data)
-                for region in regions:
-                    self._patch(schema_patch, region)
-        except IOError as e:
-            if e.errno == 2:
-                LOGGER.error("Override spec file not found: %s", filename)
-                sys.exit(1)
-            elif e.errno == 21:
-                LOGGER.error(
-                    "Override spec file references a directory, not a file: %s",
-                    filename,
-                )
-                sys.exit(1)
-            elif e.errno == 13:
-                LOGGER.error(
-                    "Permission denied when accessing override spec file: %s", filename
-                )
-                sys.exit(1)
-        except ValueError as err:
-            LOGGER.error("Override spec file %s is malformed: %s", filename, err)
-            sys.exit(1)
-
-    def _patch(self, patch: SchemaPatch, region: str) -> None:
+    def patch(self, patch: SchemaPatch, region: str) -> None:
         """Patch the schemas as needed
 
         Args:
@@ -587,7 +562,11 @@ class ProviderSchemaManager:
             except ResourceNotFoundError:
                 # Resource type doesn't exist in this region
                 continue
-            schema.patch(patches=patches)
+            try:
+                schema.patch(patches=patches)
+            except Exception as e:
+                print(f"Error applying patch {patches} for {resource_type}: {e}")
+                sys.exit(1)
 
     @lru_cache(maxsize=None)
     def get_type_getatts(self, resource_type: str, region: str) -> AttributeDict:
